/*
 *  Copyright 2012  Sebastian Gottfried <sebastiangottfried@web.de>
 *  Copyright 2015  Sebastian Gottfried <sebastiangottfried@web.de>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtGraphicalEffects 1.0
import ktouch 1.0

Item {
    id: item

    property alias blurSource: effectSource.sourceItem

    signal restartRequested()
    signal abortRequested()

    opacity: 0

    Behavior on opacity {
        NumberAnimation {
            duration: 300
            easing.type: Easing.InOutQuad
        }
    }

    function show() {
        item.opacity = 1
        groupBox.forceActiveFocus()
    }

    function hide() {
        item.opacity = 0
    }

    ShaderEffectSource {
        id: effectSource
        anchors.fill: parent
        hideSource: false
    }

    FastBlur {
        anchors.fill: parent
        source: effectSource
        radius: 25
    }

    Rectangle {
        anchors.fill: parent
        color: "#55000000"
    }

    /* swallow all mouse events */
    MouseArea {
        anchors.fill: parent
        enabled: item.opacity > 0
        hoverEnabled: true
    }


    GroupBox {
        id: groupBox
        anchors.centerIn: parent
        width: column.width + 30
        height: column.height + 30

        Column {
            id: column
            focus: true
            anchors.centerIn: parent
            spacing: 15
            width: Math.max(resumeButton.implicitWidth, restartButton.implicitWidth, returnButton.implicitWidth)

            Button {
                id: resumeButton
                iconName: "go-next-view"
                text: i18n("Resume Training")
                width: parent.width
                onClicked: hide()
            }

            Button {
                id: restartButton
                iconName: "view-refresh"
                text: i18n("Restart Lesson")
                width: parent.width
                onClicked: {
                    restartRequested()
                    hide()
                }
            }

            Button {
                id: returnButton
                iconName: "go-home"
                text: i18n("Return to Home Screen")
                width: parent.width
                onClicked: {
                    abortRequested()
                    hide()
                }
            }

            Keys.onDownPressed: {
                if (resumeButton.focus)
                    restartButton.focus = true;
                else if (restartButton.focus)
                    returnButton.focus = true;
            }

            Keys.onUpPressed: {
                if (restartButton.focus)
                    resumeButton.focus = true;
                else if (returnButton.focus)
                    restartButton.focus = true;
            }

            Keys.onEscapePressed: {
                hide()
            }
        }
    }
}
